@@ -27,11 +27,20 @@
 #include <tepl/tepl-init.h>
 #include <tepl/tepl-io-error-info-bars.h>
 #include <tepl/tepl-iter.h>
+#include <tepl/tepl-language-chooser.h>
+#include <tepl/tepl-language-chooser-dialog.h>
+#include <tepl/tepl-language-chooser-widget.h>
 #include <tepl/tepl-menu-shell.h>
 #include <tepl/tepl-metadata.h>
 #include <tepl/tepl-metadata-manager.h>
 #include <tepl/tepl-notebook.h>
 #include <tepl/tepl-panel.h>
+#include <tepl/tepl-pango.h>
+#include <tepl/tepl-prefs.h>
+#include <tepl/tepl-prefs-dialog.h>
+#include <tepl/tepl-progress-info-bar.h>
+#include <tepl/tepl-settings.h>
+#include <tepl/tepl-signal-group.h>
 #include <tepl/tepl-space-drawer-prefs.h>
 #include <tepl/tepl-statusbar.h>
 #include <tepl/tepl-style-scheme-chooser-widget.h>
